@@ -30,7 +30,7 @@ __END__
 =head1 SUPPORT
 
 Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name={{ $dist->name }}>
-(or L<mailto:bug-{{ $dist->name }}@rt.cpan.org>).
+(or L<bug-{{ $dist->name }}@rt.cpan.org|mailto:bug-{{ $dist->name }}@rt.cpan.org>).
 I am also usually active on irc, as 'ether' at C<irc.perl.org>.
 
 =head1 ACKNOWLEDGEMENTS
